==> ejc-zjkjcost-impl-3.0.0-20240322.081731-200-sources.jar: com/ejianc/business/zjkjcost/reserve/service/impl/PersonalApproveServiceImpl.java <==
package com.ejianc.business.zjkjcost.reserve.service.impl;

import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.ejianc.framework.skeleton.template.BaseServiceImpl;

import com.ejianc.business.zjkjcost.reserve.mapper.PersonalApproveMapper;
import com.ejianc.business.zjkjcost.reserve.bean.PersonalApproveEntity;
import com.ejianc.business.zjkjcost.reserve.service.IPersonalApproveService;

import java.math.BigDecimal;
import java.util.HashMap;
import java.util.List;
import java.util.Map;

/**
 * 风险预留金-个人风险金过程返还、转抵审批表
 *
 * @author generator
 *
 */
@Service("personalApproveService")
public class PersonalApproveServiceImpl extends BaseServiceImpl<PersonalApproveMapper, PersonalApproveEntity> implements IPersonalApproveService{
    @Autowired
    private PersonalApproveMapper mapper;
    @Override
    public Map<String, Object> queryTotal(Long projectId, Long applicantId) {
        Map<String,Object> map = new HashMap<>();
        map.put("projectId",projectId);
        map.put("applicantId",applicantId);
        return mapper.queryTotal(map);
    }

    @Override
    public List<Map<String,String>> selectIds(Long projectId, Long applicantId) {
        Map<String,Object> map = new HashMap<>();
        map.put("projectId",projectId);
        map.put("applicantId",applicantId);
        return mapper.selectIds(map);
    }

    @Override
    public BigDecimal queryAllocate(Long applicantId, Long projectId) {
        return mapper.queryAllocate(applicantId,projectId);
    }


}

==> ejc-zjkjcost-impl-3.0.0-20250916.084843-228-sources.jar: com/ejianc/business/zjkjcost/reserve/service/impl/PersonalApproveServiceImpl.java <==
package com.ejianc.business.zjkjcost.reserve.service.impl;

import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.ejianc.framework.skeleton.template.BaseServiceImpl;

import com.ejianc.business.zjkjcost.reserve.mapper.PersonalApproveMapper;
import com.ejianc.business.zjkjcost.reserve.bean.PersonalApproveEntity;
import com.ejianc.business.zjkjcost.reserve.service.IPersonalApproveService;

import java.math.BigDecimal;
import java.util.HashMap;
import java.util.List;
import java.util.Map;

/**
 * 风险预留金-个人风险金过程返还、转抵审批表
 *
 * @author generator
 *
 */
@Service("personalApproveService")
public class PersonalApproveServiceImpl extends BaseServiceImpl<PersonalApproveMapper, PersonalApproveEntity> implements IPersonalApproveService{
    @Autowired
    private PersonalApproveMapper mapper;
    @Override
    public Map<String, Object> queryTotal(Long projectId, Long applicantId) {
        Map<String,Object> map = new HashMap<>();
        map.put("projectId",projectId);
        map.put("applicantId",applicantId);
        return mapper.queryTotal(map);
    }

    @Override
    public List<Map<String,String>> selectIds(Long projectId, Long applyId) {
        Map<String,Object> map = new HashMap<>();
        map.put("projectId",projectId);
        map.put("applyId",applyId);
        return mapper.selectIds(map);
    }

    @Override
    public BigDecimal queryAllocate(Long applicantId, Long projectId) {
        return mapper.queryAllocate(applicantId,projectId);
    }


}
